==> kmysqladmin-0.5.1.tar.gz: kmysqladmin-0.5.1/kmysqladmin/htmlconverter.cpp <==
/***************************************************************************
                          htmlconverter.cpp  -  description                              
                             -------------------                                         
    begin                : Sat Jul 3 1999                                           
    copyright            : (C) 1999 by Rajko Albrecht                         
    email                : Rajko.Albrecht@informatik.tu-chemnitz.de                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/
#ifdef WIN32
#pragma warning ( disable : 4786 )
#endif

#include "htmlconverter.h"

#ifndef rcsid
static const char rcsid[]="$Id: htmlconverter.cpp,v 2.5 1999/10/13 00:51:21 ral Exp $";
//const char*htmlconverter_rcs(){return rcsid;}
#endif

CHtmlConverter::CHtmlConverter()
    :CConverter()
{
    source_idents.resize(11);
    source_idents[0]="&";
    source_idents[1]="\"";
    source_idents[2]="<";
    source_idents[3]=">";
    source_idents[4]="";
    source_idents[5]="";
    source_idents[6]="";
    source_idents[7]="";
    source_idents[8]="";
    source_idents[9]="";
    source_idents[10]="";
    target_idents.resize(11);
    target_idents[0]="&amp;";
    target_idents[1]="&quot;";
    target_idents[2]="&lt;";
    target_idents[3]="&gt;";
    target_idents[4]="&auml;";
    target_idents[5]="&Auml;";
    target_idents[6]="&ouml;";
    target_idents[7]="&Ouml;";
    target_idents[8]="&uuml;";
    target_idents[9]="&Uuml;";
    target_idents[10]="&szlig;";
    count = 11;
}

CHtmlConverter::~CHtmlConverter()
{
}

==> kmysqladmin-0.32.tar.gz: kmysqladmin-0.32/kmysqladmin/htmlconverter.cpp <==
/***************************************************************************
                          htmlconverter.cpp  -  description                              
                             -------------------                                         
    begin                : Sat Jul 3 1999                                           
    copyright            : (C) 1999 by Rajko Albrecht                         
    email                : Rajko.Albrecht@informatik.tu-chemnitz.de                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#include "htmlconverter.h"

#ifndef rcsid
static const char rcsid[]="$Id: htmlconverter.cpp,v 2.3 1999/07/30 00:30:36 ral Exp $";
const char*htmlconverter_rcs(){return rcsid;}
#endif

CHtmlConverter::CHtmlConverter()
    :CConverter()
{
    source_idents.resize(11);
    source_idents[0]="&";
    source_idents[1]="\"";
    source_idents[2]="<";
    source_idents[3]=">";
    source_idents[4]="";
    source_idents[5]="";
    source_idents[6]="";
    source_idents[7]="";
    source_idents[8]="";
    source_idents[9]="";
    source_idents[10]="";
    target_idents.resize(11);
    target_idents[0]="&amp;";
    target_idents[1]="&quot;";
    target_idents[2]="&lt;";
    target_idents[3]="&gt;";
    target_idents[4]="&auml;";
    target_idents[5]="&Auml;";
    target_idents[6]="&ouml;";
    target_idents[7]="&Ouml;";
    target_idents[8]="&uuml;";
    target_idents[9]="&Uuml;";
    target_idents[10]="&szlig;";
    count = 11;
}

CHtmlConverter::~CHtmlConverter()
{
}
